@@ -253,7 +253,7 @@ mod tests {
 
         let name = XorName(rand::random());
         let tag = 10;
-        let client = create_test_client(None).await?;
+        let client = create_test_client().await?;
 
         let owner = client.public_key();
         let mut perms = BTreeMap::<User, PublicPermissions>::new();
@@ -294,7 +294,7 @@ mod tests {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn register_basics() -> Result<()> {
-        let client = create_test_client(None).await?;
+        let client = create_test_client().await?;
 
         let name = XorName(rand::random());
         let tag = 15000;
@@ -339,7 +339,7 @@ mod tests {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn register_private_permissions() -> Result<()> {
-        let client = create_test_client(None).await?;
+        let client = create_test_client().await?;
         let name = XorName(rand::random());
         let tag = 15000;
         let owner = client.public_key();
@@ -382,7 +382,7 @@ mod tests {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn register_public_permissions() -> Result<()> {
-        let client = create_test_client(None).await?;
+        let client = create_test_client().await?;
 
         let name = XorName(rand::random());
         let tag = 15000;
@@ -425,7 +425,7 @@ mod tests {
     async fn register_write() -> Result<()> {
         let name = XorName(rand::random());
         let tag = 10;
-        let client = create_test_client(None).await?;
+        let client = create_test_client().await?;
 
         let owner = client.public_key();
         let mut perms = BTreeMap::<User, PublicPermissions>::new();
@@ -503,7 +503,7 @@ mod tests {
     async fn register_owner() -> Result<()> {
         let name = XorName(rand::random());
         let tag = 10;
-        let client = create_test_client(None).await?;
+        let client = create_test_client().await?;
 
         let owner = client.public_key();
         let mut perms = BTreeMap::<PublicKey, PrivatePermissions>::new();
@@ -522,7 +522,7 @@ mod tests {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn register_can_delete_private() -> Result<()> {
-        let mut client = create_test_client(None).await?;
+        let mut client = create_test_client().await?;
         let name = XorName(rand::random());
         let tag = 15000;
         let owner = client.public_key();
@@ -564,7 +564,7 @@ mod tests {
 
     #[tokio::test(flavor = "multi_thread")]
     async fn register_cannot_delete_public() -> Result<()> {
-        let client = create_test_client(None).await?;
+        let client = create_test_client().await?;
 
         let name = XorName(rand::random());
         let tag = 15000;
